Change

Enum Change 

pub enum Change<T = ()> {
    InsertedAt(usize),
    RemovedAt(usize),
    ReplacedAt(usize),
    Culled(usize),
    Event(T),
}
Describes a reason why the Score of transactions should be updated. The Scoring implementations can use this information to update the Score table more efficiently.

Variants



InsertedAt(usize)

New transaction has been inserted at given index. The Score at that index is initialized with default value and needs to be filled in.



RemovedAt(usize)

The transaction has been removed at given index and other transactions shifted to it’s place. The scores were removed and shifted as well. For simple scoring algorithms no action is required here.



ReplacedAt(usize)

The transaction at given index has replaced a previous transaction. The score at that index needs to be update (it contains value from previous transaction).



Culled(usize)

Given number of stalled transactions has been culled from the beginning. The scores has been removed from the beginning as well. For simple scoring algorithms no action is required here.



Event(T)

Custom event to update the score triggered outside of the pool. Handling this event is up to scoring implementation.